@@ -25,7 +25,7 @@ from session_function import client_post_cert
 from calculate.core.client.cert_verify import VerifyError
 
 from client_class import Client_suds, HTTPSClientCertTransport
-from more import post_connect_action, show_msg, uniq, LabelWordWrap
+from more import post_connect_action, show_msg, uniq, LabelWordWrap, get_icon
 
 class LocalhostPasswd(qt.QDialog):
     def __init__(self, parent):
@@ -123,7 +123,7 @@ class FrameConnection(qt.QWidget):
         grid.addWidget(self.text_passwd, 2, 1)
 
         self.cmd_connect = qt.QPushButton(_('Connect'), self)
-        self.cmd_connect.setIcon(qt.QIcon.fromTheme("network-connect"))
+        self.cmd_connect.setIcon(get_icon("network-connect"))
         self.cmd_connect.setDefault(True)
         self.cmd_connect.setAutoDefault(True)
 #        self.cmd_connect.setMaximumWidth(120)
@@ -157,7 +157,7 @@ class FrameConnection(qt.QWidget):
                   window.geometry().y() + window.geometry().height() / 2 \
                   - self.sizeHint().height() / 2)
         self.setWindowTitle(_('Connection'))
-        self.setWindowIcon(qt.QIcon.fromTheme("network-connect"))
+        self.setWindowIcon(get_icon("network-connect"))
         
     def set_disabled(self):
 
